@@ -1,10 +1,9 @@
 from .alembic_cmds import register as register_alembic
 from .scaffold_cmds import register as register_scaffold
-from .app_cmds import register as register_app, HELP
+from .help import _HELP
 
 __all__ = [
     "register_alembic",
     "register_scaffold",
-    "register_app",
-    "HELP",
+    "_HELP",
 ]
\ No newline at end of file
